@@ -41,6 +41,8 @@ OC.L10N.register(
     "Comment:" : "ملاحظات:",
     "You have a new appointment booking \"%s\" from %s" : "لديك حجز موعدٍ جديدٍ \"%s\" من %s",
     "Dear %s, %s (%s) booked an appointment with you." : "السيد/السيدة %s, %s (%s) حجز موعداً معك.",
+    "Location:" : "المكان :",
+    "Duration:" : "المدة الزمنية:",
     "A Calendar app for Nextcloud" : "تطبيق التقويم لـ نكست كلاود",
     "Previous day" : "أمس",
     "Previous week" : "الأسبوع الماضي",
@@ -147,6 +149,8 @@ OC.L10N.register(
     "Share calendar" : "مُشاركة التقويم",
     "Unshare from me" : "أنت ألغيت المشاركة",
     "Save" : "حفظ",
+    "No title" : "بدون عنوان",
+    "View" : "عرض",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
     "Filename" : "اسم الملف",
@@ -164,8 +168,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["تم استيراد %n أحداث بنجاح","تم استيراد %n حدث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح"],
     "Import partially failed. Imported {accepted} out of {total}." : "الاستيراد فشل جزئيّاً. تمّ استيراد {accepted} من مجموع {total}.",
     "Automatic" : "تلقائي",
-    "Automatic ({detected})" : "تلقائي ({detected})",
+    "Automatic ({timezone})" : "تلقائي ({timezone})",
     "New setting was not saved successfully." : "لم يتم حفظ الاعدادات الجديدة.",
+    "Timezone" : "المنطقة الزمنية",
     "Navigation" : "التنقل",
     "Previous period" : "الفترة السابقة",
     "Next period" : "الفترة القادمة",
@@ -183,7 +188,6 @@ OC.L10N.register(
     "Save edited event" : "حفظ تعديلات الأحداث",
     "Delete edited event" : "حذف الأحداث المحررة",
     "Duplicate event" : "تكرار الحدث",
-    "Shortcut overview" : "نظرة عامة للاختصارات",
     "or" : "او",
     "Calendar settings" : "إعدادات التقويم",
     "At event start" : "في بداية الحدث",
@@ -191,19 +195,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "تعذّر حفظ التقويم التلقائي",
     "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
     "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
-    "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
-    "Show tasks in calendar" : "إظهار المهام في التقويم",
-    "Enable simplified editor" : "تفعيل المحرر البسيط",
-    "Limit the number of events displayed in the monthly view" : "تقييد عدد الأحداث التي تُعرض في العرض الشهري",
-    "Show weekends" : "إظهار أيام نهاية الاسبوع",
-    "Show week numbers" : "إظهار أرقام الأسابيع",
-    "Time increments" : "زيادات الوقت",
-    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
-    "Default reminder" : "التذكير الافتراضي",
+    "General" : "عامٌّ",
+    "Personal availability settings" : "إعدادات التواجد الشخصي",
     "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
     "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
-    "Personal availability settings" : "إعدادات التواجد الشخصي",
-    "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح",
+    "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
+    "Show tasks in calendar" : "إظهار المهام في التقويم",
+    "Show weekends" : "إظهار أيام نهاية الاسبوع",
+    "Show week numbers" : "إظهار أرقام الأسابيع",
+    "Editing" : "جارِ التعديل",
+    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
+    "Default reminder" : "التذكير الافتراضي",
+    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح",
     "Appointment schedule successfully created" : "تمّ إنشاء جدول المواعيد بنجاح",
     "Appointment schedule successfully updated" : "تمّ تحديث جدول المواعيد بنجاح",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} دقائق","{duration} دقيقة","{duration} دقائق","{duration} دقائق","{duration} دقائق","{duration} دقائق"],
@@ -416,6 +419,10 @@ OC.L10N.register(
     "Update this occurrence" : "تحديث هذا الحدوث",
     "Public calendar does not exist" : "التقويم العام غير موجود",
     "Maybe the share was deleted or has expired?" : "لربما كانت المشاركة محذوفة أو منتهية الصلاحية؟",
+    "Yes" : "نعم",
+    "No" : "لا",
+    "Maybe" : "ربما",
+    "Create" : "إنشاء",
     "from {formattedDate}" : "من {formattedDate}",
     "to {formattedDate}" : "إلى {formattedDate}",
     "on {formattedDate}" : "في {formattedDate}",
@@ -476,6 +483,11 @@ OC.L10N.register(
     "Untitled event" : "حدث بدون اسم",
     "Close" : "إغلاق",
     "Modifications will not get propagated to the organizer and other attendees" : "التعديلات لن يتم إذاعتها على المنظم والمشاركين الآخرين",
+    "Selected" : "مُحدّدة",
+    "Title" : "العنوان",
+    "30 min" : "30 دقيقة",
+    "Participants" : "المشارِكون",
+    "Submit" : "إرسال ",
     "Subscribe to {name}" : "اشتراك مع {name}",
     "Export {name}" : "تصدير {name}",
     "Show availability" : "أعرُض التوافر",
@@ -576,6 +588,12 @@ OC.L10N.register(
     "This is an event reminder." : "هذا تذكير بحدث",
     "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
     "Appointment not found" : "الموعد غير موجود",
-    "User not found" : "المستخدم غير موجود"
+    "User not found" : "المستخدم غير موجود",
+    "Automatic ({detected})" : "تلقائي ({detected})",
+    "Shortcut overview" : "نظرة عامة للاختصارات",
+    "Enable simplified editor" : "تفعيل المحرر البسيط",
+    "Limit the number of events displayed in the monthly view" : "تقييد عدد الأحداث التي تُعرض في العرض الشهري",
+    "Time increments" : "زيادات الوقت",
+    "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
