@@ -12,6 +12,8 @@ OC.L10N.register(
     "Upcoming events" : "Darvoudoù da zont",
     "Calendar" : "Deiziataer",
     "Confirm" : "Kadarnañ",
+    "Date:" : "Deiziad:",
+    "Location:" : "Lec'h :",
     "A Calendar app for Nextcloud" : "Un arload Deiziataerioù evit Nextcloud",
     "Previous day" : "Deizioù kent",
     "Previous week" : "Sizhun kent",
@@ -29,31 +31,37 @@ OC.L10N.register(
     "Edit" : "Cheñch",
     "Delete" : "Dilemel",
     "Create new" : "Krouiñ unan nevez",
+    "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
     "Untitled calendar" : "Deiziataer hep titl",
     "Shared with you by" : "Rannet deoc'h gant",
-    "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Paouezet e vo da lodañ an deiziataer a-benn {countdown} eilenn"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dilamet e vo an deiziataer a-benn {countdown} eilenn"],
-    "Calendars" : "Deiziadurioù",
+    "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
+    "Calendars" : "Deiziataerioù",
     "New calendar" : "Deizataer nevez",
     "Creating calendar …" : "Krouiñ un deizataer ...",
     "New calendar with task list" : "Deizataer nevez gant ur roll ober",
     "New subscription from link (read-only)" : "Koumanant nevez dre liamm (lenn nemetken)",
     "Creating subscription …" : "Krouiñ ur goumanant ...",
-    "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
+    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
+    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
     "Copy subscription link" : "Eilañ al liamm koumanantiñ",
     "Copying link …" : "Oc'h eilañ al liamm  ...",
     "Copied link" : "Liamm eilet",
     "Could not copy link" : "N'eus ket bet gallet eilañ al liamm",
-    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
-    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
+    "Empty trash bin" : "Pod-lastez goullo",
     "Name" : "Anv",
-    "Deleted" : "Lamet",
+    "Deleted" : "Dilamet",
     "Restore" : "Adkrouiñ",
     "Delete permanently" : "Lamet da viken",
-    "Empty trash bin" : "Pod-lastez goullo",
     "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
+    "Hidden" : "Koachet",
+    "An error occurred, unable to publish calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket embann an deiziataer.",
+    "An error occurred, unable to send email." : "C'hoarvezet ez eus ur fazi, ne c'haller ket kas ar postel",
+    "Embed code copied to clipboard." : "Eilet eo bet ar c'hod enframmañ er golver",
+    "Embed code could not be copied to clipboard." : "N'eus ket bet gallet eilañ ar c'hod enframmañ er golver.",
+    "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
     "Share link" : "Lodañ al liamm",
     "Copy public link" : "Eilañ al liamm foran",
     "Send link to calendar via email" : "Kas al liamm d'an deiziataer dre bostel",
@@ -65,37 +73,41 @@ OC.L10N.register(
     "Could not copy code" : "N'eus ket bet gallet eilañ ar c'hod",
     "Delete share link" : "Dilamet eo bet al liamm lodañ",
     "Deleting share link …" : "O tilemel al liamm lodañ...",
-    "An error occurred, unable to publish calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket embann an deiziataer.",
-    "An error occurred, unable to send email." : "C'hoarvezet ez eus ur fazi, ne c'haller ket kas ar postel",
-    "Embed code copied to clipboard." : "Eilet eo bet ar c'hod enframmañ er golver",
-    "Embed code could not be copied to clipboard." : "N'eus ket bet gallet eilañ ar c'hod enframmañ er golver.",
-    "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
+    "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
     "can edit" : "posuple eo embann",
     "Unshare with {displayName}" : "Dirannañ gant {displayName}",
-    "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
     "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
     "No users or groups" : "Implijourienn pe strodadoù ebet",
     "Unshare from me" : "Paouez da lodañ ganin",
     "Save" : "Enrollañ",
+    "View" : "Gwell",
     "Import calendars" : "Emporzhiañ deizataerioù",
     "Please select a calendar to import into …" : "Choazit un deizataer de emporzhiañ e-barzh ...",
     "Filename" : "Anv restr",
     "Calendar to import into" : "Deizataer de emporzhiañ e-barzh",
-    "Cancel" : "Arrest",
+    "Cancel" : "Nullañ",
     "_Import calendar_::_Import calendars_" : ["Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer"],
     "{filename} could not be parsed" : "{filename} na c'hell ket bezhañ dielfennet",
     "No valid files found, aborting import" : "Restr mat kavet ebet, arrestet e vez an emporzhiañ",
     "Import partially failed. Imported {accepted} out of {total}." : "Emporzhiañ damc'hwitet. Emporzhiet {accepted} diwar {total}.",
+    "Automatic" : "Otomatek",
     "List view" : "Gwelidik listenn",
     "Actions" : "Oberoù",
+    "General" : "Hollek",
+    "Update" : "Hizivaat",
     "Location" : "Lec'hiadur",
     "Description" : "Deskrivadur",
     "Add" : "Ouzhpennañ",
     "Monday" : "Lun",
-    "Update" : "Hizivaat",
+    "Wednesday" : "Merc'her",
+    "Friday" : "Gwener",
+    "Sunday" : "Sul",
     "Your email address" : "O chom-lec'h postel",
+    "Select conversation" : "Choaz un diviz",
     "Notification" : "Kemennadenn",
     "Email" : "Postel",
+    "hours" : "eur",
+    "days" : "devezh",
     "Delete file" : "Dilemel ar restr",
     "Available" : "Vak",
     "Not available" : "Divak",
@@ -109,11 +121,15 @@ OC.L10N.register(
     "never" : "james",
     "after" : "goude",
     "first" : "kentañ",
-    "third" : "trede",
+    "Remove participant" : "Disachañ an den",
+    "No" : "Ket",
     "Global" : "Hollek",
     "Personal" : "Personel",
-    "Details" : "Munudoù",
     "Close" : "Serriñ",
+    "Selected" : "Choazet",
+    "Title" : "Titl",
+    "Participants" : "Tud",
+    "Submit" : "Kinnig",
     "Daily" : "Pemdeziek",
     "Weekly" : "Sizhuniek",
     "Monthly" : "Miziek",
@@ -123,6 +139,8 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Bep miz","Bep %n viz","Bep %n miz","Bep %n miz","Bep %n miz"],
     "_Every %n year_::_Every %n years_" : ["Bep bloaz","Bep %n vloaz","Bep %n bloaz","Bep %n bloaz","Bep %n bloaz"],
     "_on {weekday}_::_on {weekdays}_" : ["d'al {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}"],
+    "third" : "trede",
+    "W" : "S",
     "%n more" : "%n ouzhpenn",
     "No events to display" : "Darvoud ebet da ziskouez",
     "No events" : "Darvoud ebet",
@@ -133,7 +151,6 @@ OC.L10N.register(
     "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
     "The visibility of this event in shared calendars." : "Gweluster an darvoud-mañ en deiziataerioù lodet.",
     "Add a location" : "Ouzhpennañ ul lec'hiadur",
-    "Add a description" : "Ouzhpennañ un deskrivadur",
     "Status" : "Statud",
     "Confirmed" : "Kadarnaet",
     "Canceled" : "Nullet",
@@ -147,11 +164,7 @@ OC.L10N.register(
     "Custom color" : "Liv personelaet",
     "Special color of this event. Overrides the calendar-color." : "Liv dibar evit an darvoud-mañ. Diverkañ liv an deiziataer",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Chat room for event" : "Sal-flapiñ evit un darvoud",
     "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
-    "Imported {filename}" : "Enporzhiet {filename}",
-    "[Today]" : "[Hiziv]",
-    "[Tomorrow]" : "[Warc'hoazh]",
-    "[Yesterday]" : "[Dec'h]"
+    "Imported {filename}" : "Enporzhiet {filename}"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
