@@ -149,8 +149,9 @@ OC.L10N.register(
     "No valid files found, aborting import" : "לא נמצאו קבצים תקפים, הייבוא מבוטל",
     "Import partially failed. Imported {accepted} out of {total}." : "הייבוא נכשל חלקית. מיובא {accepted} מתוך {total}.",
     "Automatic" : "אוטומטי",
-    "Automatic ({detected})" : "אוטומטי ({detected})",
+    "Automatic ({timezone})" : "אוטומטי ({timezone})",
     "New setting was not saved successfully." : "ההגדרה החדשה לא נשמרה בהצלחה.",
+    "Timezone" : "אזור זמן",
     "Navigation" : "ניווט",
     "Previous period" : "התקופה הקודמת",
     "Next period" : "התקופה הבאה",
@@ -162,19 +163,18 @@ OC.L10N.register(
     "Actions" : "פעולות",
     "Create event" : "יצירת אירוע",
     "Show shortcuts" : "הצגת קיצורי דרך",
-    "Shortcut overview" : "סקירת קיצור דרך",
     "or" : "או",
     "No reminder" : "אין תזכורת",
     "CalDAV link copied to clipboard." : "קישור ה־CalDAV הועתק ללוח הגזירים.",
     "CalDAV link could not be copied to clipboard." : "לא ניתן להעתיק את קישור ה־CalDAV ללוח הגזירים.",
-    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
-    "Show tasks in calendar" : "הצג משימות בלוח השנה",
-    "Enable simplified editor" : "אפשר עורך פשוט",
-    "Show weekends" : "הצגת סופי שבוע",
-    "Show week numbers" : "הצגת מספרי שבועות",
+    "General" : "כללי",
     "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
     "Copy iOS/macOS CalDAV address" : "העתקת כתובת CalDAV ל־iOS/macOS",
-    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
+    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
+    "Show tasks in calendar" : "הצג משימות בלוח השנה",
+    "Show weekends" : "הצגת סופי שבוע",
+    "Show week numbers" : "הצגת מספרי שבועות",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
     "Update" : "עדכון",
     "Location" : "מיקום",
     "Description" : "תיאור",
@@ -291,6 +291,7 @@ OC.L10N.register(
     "Untitled event" : "אירוע ללא כותרת",
     "Close" : "סגירה",
     "Participants" : "משתתפים",
+    "Submit" : "שליחה",
     "Subscribe to {name}" : "הרשמה אל {name}",
     "Anniversary" : "יום השנה",
     "Appointment" : "פגישה",
@@ -371,6 +372,10 @@ OC.L10N.register(
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
     "Imported {filename}" : "יובא {filename} ",
-    "User not found" : "המשתמש לא נמצא"
+    "User not found" : "המשתמש לא נמצא",
+    "Automatic ({detected})" : "אוטומטי ({detected})",
+    "Shortcut overview" : "סקירת קיצור דרך",
+    "Enable simplified editor" : "אפשר עורך פשוט",
+    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
