@@ -37,6 +37,7 @@ OC.L10N.register(
     "Comment:" : "Komentar:",
     "You have a new appointment booking \"%s\" from %s" : "Anda memiliki pemesanan janji temu baru \"%s\" dari %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Kepada %s, %s (%s) memesan janji temu dengan Anda.",
+    "Location:" : "Lokasi:",
     "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
     "Previous day" : "Hari sebelum",
     "Previous week" : "Minggu sebelum",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "Save" : "Simpan",
+    "View" : "Tampilan",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
@@ -140,7 +142,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
     "Automatic" : "Otomatis",
-    "Automatic ({detected})" : "Otomatis ({detected})",
+    "Automatic ({timezone})" : "Otomatis ({timezone})",
     "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
     "Navigation" : "Navigasi",
     "Previous period" : "Periode sebelum",
@@ -153,18 +155,18 @@ OC.L10N.register(
     "Actions" : "Tindakan",
     "Create event" : "Buat acara",
     "Show shortcuts" : "Tampilkan pintasan",
-    "Shortcut overview" : "Ikhtisar pintasan",
     "or" : "atau",
     "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
     "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
-    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
-    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
-    "Enable simplified editor" : "Aktifkan editor serderhana",
-    "Show weekends" : "Tampilkan akhir pekan",
-    "Show week numbers" : "Tampilkan nomor pekan",
+    "General" : "Umum",
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
     "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
-    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
+    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
+    "Show weekends" : "Tampilkan akhir pekan",
+    "Show week numbers" : "Tampilkan nomor pekan",
+    "Editing" : "Pengeditan",
+    "Keyboard shortcuts" : "Pintasan keyboard",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
@@ -257,6 +259,7 @@ OC.L10N.register(
     "Resources" : "Sumber daya",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
+    "Create" : "Buat",
     "on {formattedDate}" : "dalam {formattedDate}",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
@@ -341,7 +344,9 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "This is an event reminder." : "Ini adalah pengingat acara.",
-    "+ Add reminder" : "+ Tambah pengingat",
-    "Details" : "Detail"
+    "Automatic ({detected})" : "Otomatis ({detected})",
+    "Shortcut overview" : "Ikhtisar pintasan",
+    "Enable simplified editor" : "Aktifkan editor serderhana",
+    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci"
 },
 "nplurals=1; plural=0;");
