@@ -165,8 +165,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nイベントのインポートに成功しました"],
     "Import partially failed. Imported {accepted} out of {total}." : "インポートが部分的に失敗しました。 {total}のうち{accepted}をインポートしました。",
     "Automatic" : "自動",
-    "Automatic ({detected})" : "自動 ({detected})",
+    "Automatic ({timezone})" : "自動 ({timezone})",
     "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
+    "Timezone" : "タイムゾーン",
     "Navigation" : "ナビゲーション",
     "Previous period" : "前の期間",
     "Next period" : "次の期間",
@@ -184,7 +185,6 @@ OC.L10N.register(
     "Save edited event" : "編集したイベントを保存",
     "Delete edited event" : "編集したイベントを削除",
     "Duplicate event" : "イベントを複製",
-    "Shortcut overview" : "概要",
     "or" : "或いは",
     "Calendar settings" : "カレンダー設定",
     "At event start" : "イベント開始時",
@@ -192,19 +192,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "デフォルトカレンダーの保存に失敗しました",
     "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
     "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
-    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
-    "Show tasks in calendar" : "カレンダーにタスクを表示",
-    "Enable simplified editor" : "簡易エディターを有効にする",
-    "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
-    "Show weekends" : "週末を表示する",
-    "Show week numbers" : "週番号を表示する",
-    "Time increments" : "時間の増加",
-    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
-    "Default reminder" : "既定のリマインダー",
+    "General" : "一般",
+    "Personal availability settings" : "個人の稼働率設定",
     "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
-    "Personal availability settings" : "個人の稼働率設定",
-    "Show keyboard shortcuts" : "キーボード ショートカット",
+    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
+    "Show tasks in calendar" : "カレンダーにタスクを表示",
+    "Show weekends" : "週末を表示する",
+    "Show week numbers" : "週番号を表示する",
+    "Editing" : "編集中",
+    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
+    "Default reminder" : "既定のリマインダー",
+    "Keyboard shortcuts" : "キーボードショートカット",
     "Appointment schedule successfully created" : "予約スケジュールの作成に成功しました",
     "Appointment schedule successfully updated" : "予約スケジュールの更新に成功しました",
     "_{duration} minute_::_{duration} minutes_" : ["{duration}分"],
@@ -394,6 +393,8 @@ OC.L10N.register(
     "Update this occurrence" : "この出来事を更新する",
     "Public calendar does not exist" : "公開カレンダーは存在しません",
     "Maybe the share was deleted or has expired?" : "共有が削除されたか、期限切れの可能性があります",
+    "Yes" : "はい",
+    "No" : "いいえ",
     "Maybe" : "たぶん",
     "Create" : "作成",
     "from {formattedDate}" : "{formattedDate}から",
@@ -454,7 +455,10 @@ OC.L10N.register(
     "Untitled event" : "無題のイベント",
     "Close" : "閉じる",
     "Selected" : "選択済み",
+    "Title" : "タイトル",
+    "30 min" : "30分",
     "Participants" : "参加者",
+    "Submit" : "提出する",
     "Subscribe to {name}" : "{name} を購読する",
     "Export {name}" : "エクスポート {name}",
     "Anniversary" : "記念日",
@@ -546,6 +550,12 @@ OC.L10N.register(
     "Imported {filename}" : "インポートされた {filename}",
     "This is an event reminder." : "これはイベントのリマインダーです。",
     "Appointment not found" : "予定が見つかりません",
-    "User not found" : "ユーザーが見つかりません"
+    "User not found" : "ユーザーが見つかりません",
+    "Automatic ({detected})" : "自動 ({detected})",
+    "Shortcut overview" : "概要",
+    "Enable simplified editor" : "簡易エディターを有効にする",
+    "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
+    "Time increments" : "時間の増加",
+    "Show keyboard shortcuts" : "キーボード ショートカット"
 },
 "nplurals=1; plural=0;");
