@@ -2,7 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Provided email-address is too long" : "Norādītā e-pasta adrese ir pārāk gara",
-    "User-Session unexpectedly expired" : "Lietotāja sesija ir negaidīti beigusies",
+    "User-Session unexpectedly expired" : "Lietotāja sesija negaidīti beidzās",
     "Provided email-address is not valid" : "Norādītā e-pasta adrese nav derīga",
     "%s has published the calendar »%s«" : "%s dalījās ar kalendāru »%s«",
     "Unexpected error sending email. Please contact your administrator." : "E-pasta ziņojuma nosūtīšanas laikā bija neparedzēta kļūda. Lūgums sazināties ar savu pārvaldītāju.",
@@ -152,8 +152,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sekmīgi ievietoti %n notikumi","Sekmīgi ievietots %n notikums","Sekmīgi ievietoti %n notikumi"],
     "Import partially failed. Imported {accepted} out of {total}." : "Ievietošana daļēji neizdevās. Ievietoti {accepted} no {total}.",
     "Automatic" : "Automātisks",
-    "Automatic ({detected})" : "Automātiska ({detected})",
+    "Automatic ({timezone})" : "Automātiski ({timezone})",
     "New setting was not saved successfully." : "Jauna iestatījuma saglabāšana neizdevās.",
+    "Timezone" : "Laika josla",
     "Navigation" : "Navigācija",
     "Previous period" : "Iepriekšējais laika posms",
     "Next period" : "Nākamais periods",
@@ -171,24 +172,23 @@ OC.L10N.register(
     "Save edited event" : "Saglabāt laboto notikumu",
     "Delete edited event" : "Izdzēst laboto notikumu",
     "Duplicate event" : "Pavairot notikumu",
-    "Shortcut overview" : "Īsceļu pārskats",
     "or" : "vai",
     "Calendar settings" : "Kalendāra iestatījumi",
     "No reminder" : "Nav atgādinājuma",
     "Failed to save default calendar" : "Neizdevās saglabāt noklusējuma kalendāru",
     "CalDAV link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
     "CalDAV link could not be copied to clipboard." : "Kalendāra saiti neizdevās ievietot starpliktuvē.",
-    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
-    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
-    "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
-    "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
-    "Show weekends" : "Rādīt nedēļas nogales",
-    "Show week numbers" : "Rādīt nedēļu numurus",
-    "Default reminder" : "Noklusējuma atgādinājums",
+    "General" : "Vispārīgi",
+    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
     "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
     "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
-    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
-    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
+    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
+    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
+    "Show weekends" : "Rādīt nedēļas nogales",
+    "Show week numbers" : "Rādīt nedēļu numurus",
+    "Editing" : "Labošana",
+    "Default reminder" : "Noklusējuma atgādinājums",
+    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minūšu","{duration} minūte","{duration} minūtes"],
     "0 minutes" : "0 minūtes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} stundu","{duration} stunda","{duration} stundas"],
@@ -341,6 +341,8 @@ OC.L10N.register(
     "Update this occurrence" : "Atjaunināt šo notikumu",
     "Public calendar does not exist" : "Publiskais kalendārs nepastāv",
     "Maybe the share was deleted or has expired?" : "Varbūt kopīgojums tika izdzēsts, vai arī ir beidzies tā derīgums?",
+    "Yes" : "Jā",
+    "No" : "Nē",
     "from {formattedDate}" : "no {formattedDate}",
     "to {formattedDate}" : "līdz {formattedDate}",
     "from {formattedDate} at {formattedTime}" : "no {formattedDate} plkst. {formattedTime}",
@@ -380,7 +382,9 @@ OC.L10N.register(
     "Untitled event" : "Nenosaukts notikums",
     "Close" : "Aizvērt",
     "Selected" : "Atlasītās",
+    "Title" : "Virsraksts",
     "Participants" : "Dalībnieki",
+    "Submit" : "Iesniegt",
     "Subscribe to {name}" : "Abonēt {name}",
     "Export {name}" : "Izgūt {name}",
     "Anniversary" : "Gadadiena",
@@ -460,6 +464,11 @@ OC.L10N.register(
     "Imported {filename}" : "Ievietota {filename}",
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
-    "User not found" : "Lietotājs nav atrasts"
+    "User not found" : "Lietotājs nav atrasts",
+    "Automatic ({detected})" : "Automātiska ({detected})",
+    "Shortcut overview" : "Īsceļu pārskats",
+    "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
+    "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
+    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
