@@ -32,6 +32,8 @@ OC.L10N.register(
     "Where:" : "Local:",
     "Comment:" : "Comentário:",
     "You have a new appointment booking \"%s\" from %s" : "Tem uma nova reserva de marcação \"%s\" de %s",
+    "Location:" : "Localização:",
+    "Duration:" : "Duração:",
     "A Calendar app for Nextcloud" : "Uma aplicação de calendário para o Nextcloud",
     "Previous day" : "Dia anterior",
     "Previous week" : "Semana anterior",
@@ -118,6 +120,7 @@ OC.L10N.register(
     "Share calendar" : "Partilhar calendário",
     "Unshare from me" : "Cancelar partilha",
     "Save" : "Guardar",
+    "View" : "Ver",
     "Import calendars" : "Importar calendários",
     "Please select a calendar to import into …" : "Selecione o calendário para onde importar ...",
     "Filename" : "Nome do ficheiro",
@@ -128,7 +131,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "A importação foi cancelada pois não foram encontrados ficheiros válidos",
     "Import partially failed. Imported {accepted} out of {total}." : "A importação falhou parcialmente. Importados {accepted} de um total de {total}.",
     "Automatic" : "Automático",
-    "Automatic ({detected})" : "Automático ({detected})",
+    "Automatic ({timezone})" : "Automático ({timezone})",
     "New setting was not saved successfully." : "Erro a gravar a nova configuração.",
     "Navigation" : "Navegação",
     "Previous period" : "Período anterior",
@@ -146,23 +149,22 @@ OC.L10N.register(
     "Save edited event" : "Gravar evento editado",
     "Delete edited event" : "Apagar evento editado",
     "Duplicate event" : "Duplicar evento",
-    "Shortcut overview" : "Visão geral de atalhos",
     "or" : "ou",
     "Calendar settings" : "Configurações do calendário",
     "No reminder" : "Nenhum lembrete",
     "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
     "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
-    "Enable birthday calendar" : "Ativar calendário de aniversários",
-    "Show tasks in calendar" : "Mostrar tarefas no calendário",
-    "Enable simplified editor" : "Ativar editor simplificado",
-    "Show weekends" : "Mostrar fins-de-semana",
-    "Show week numbers" : "Mostrar o número das semanas",
-    "Time increments" : "Incrementos de tempo",
-    "Default reminder" : "Lembrete padrão",
+    "General" : "Geral",
+    "Personal availability settings" : "Configurações de disponibilidade pessoal",
     "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
     "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
-    "Personal availability settings" : "Configurações de disponibilidade pessoal",
-    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
+    "Enable birthday calendar" : "Ativar calendário de aniversários",
+    "Show tasks in calendar" : "Mostrar tarefas no calendário",
+    "Show weekends" : "Mostrar fins-de-semana",
+    "Show week numbers" : "Mostrar o número das semanas",
+    "Editing" : "A editar",
+    "Default reminder" : "Lembrete padrão",
+    "Keyboard shortcuts" : "Atalhos de teclado",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -204,10 +206,8 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Por favor partilhe qualquer coisa que ajude na preparação da nossa reunião",
     "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível agendar a reunião. Tente novamente mais tarde ou entre em contacto com o organizador.",
     "Back" : "Voltar",
-    "Create a new conversation" : "Criar nova conversa",
     "on" : "em",
     "at" : "às",
-    "Reminder" : "Lembrete",
     "before at" : "antes em",
     "Notification" : "Notificação",
     "Email" : "E-mail",
@@ -218,7 +218,6 @@ OC.L10N.register(
     "Edit time" : "Editar horário",
     "Save time" : "Gravar horário",
     "Remove reminder" : "Apagar lembrete",
-    "+ Add reminder" : "+ Adicionar lembrete",
     "Add reminder" : "Adicionar lembrete ",
     "seconds" : "segundos",
     "minutes" : "minutos",
@@ -236,12 +235,13 @@ OC.L10N.register(
     "Not available" : "Indisponível",
     "Invitation declined" : "Convite recusado",
     "Checking availability" : "A verificar disponibilidade",
-    "Free" : "Livre",
-    "Busy" : "Ocupado",
     "Out of office" : "Fora do escritório",
-    "Unknown" : "Desconhecido",
+    "Attendees:" : "Participantes:",
     "Done" : "Concluído",
     "Room name" : "Nome da sala",
+    "Free" : "Livre",
+    "Busy" : "Ocupado",
+    "Unknown" : "Desconhecido",
     "The invitation has been accepted successfully." : "O convite foi aceite com sucesso.",
     "Failed to accept the invitation." : "Falha ao aceitar o convite.",
     "The invitation has been declined successfully." : "O convite foi recusado com sucesso.",
@@ -251,7 +251,6 @@ OC.L10N.register(
     "Attendees" : "Participantes",
     "From" : "De",
     "To" : "Para",
-    "All day" : "Todo o dia",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "depois",
@@ -265,17 +264,25 @@ OC.L10N.register(
     "_year_::_years_" : ["ano","anos","anos"],
     "weekday" : "dia da semana",
     "weekend day" : "dia do fim-de-semana",
+    "Resources" : "Recursos",
     "available" : "disponível",
+    "Yes" : "Sim",
+    "No" : "Não",
+    "Create" : "Criar",
     "Pick a date" : "Escolha uma data",
     "Global" : "Global",
     "Subscribed" : "Subscrito",
     "Subscribe" : "Subscrever",
     "Personal" : "Pessoal",
-    "Details" : "Detalhes",
+    "Edit event" : "Editar evento",
+    "All day" : "Todo o dia",
     "Invite" : "Convite",
-    "Resources" : "Recursos",
     "Untitled event" : "Evento sem título",
     "Close" : "Fechar",
+    "Selected" : "Selecionado",
+    "Title" : "Título",
+    "Participants" : "Participantes",
+    "Submit" : "Submeter",
     "Anniversary" : "Aniversário",
     "Miscellaneous" : "Diversos",
     "Week {number} of {year}" : "Semana {number} do {year}",
@@ -298,6 +305,11 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "Error while sharing file" : "Erro ao partilhar ficheiro",
     "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
-    "User not found" : "Utilizador não encontrado"
+    "User not found" : "Utilizador não encontrado",
+    "Automatic ({detected})" : "Automático ({detected})",
+    "Shortcut overview" : "Visão geral de atalhos",
+    "Enable simplified editor" : "Ativar editor simplificado",
+    "Time increments" : "Incrementos de tempo",
+    "Show keyboard shortcuts" : "Mostrar atalhos de teclado"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
