@@ -156,7 +156,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["A fost importat %n eveniment","Au fost importate %n evenimente","Au fost importate %n evenimente"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importarea a eşuat parţial. S-au importat  {accepted} din {total}.",
     "Automatic" : "Automat",
-    "Automatic ({detected})" : "Automat ({detectat})",
+    "Automatic ({timezone})" : "Automat ({detectat})",
     "New setting was not saved successfully." : "Noile setări nu au fost salvate cu succes.",
     "Navigation" : "Navigare",
     "Previous period" : "Perioada anterioară",
@@ -174,24 +174,22 @@ OC.L10N.register(
     "Save edited event" : "Salvează evenimentul editat",
     "Delete edited event" : "Șterge evenimentul editat",
     "Duplicate event" : "Duplicare eveniment",
-    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
     "or" : "sau",
     "Calendar settings" : "Setări calendar",
     "No reminder" : "Fără mementouri",
     "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
     "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
-    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
-    "Show tasks in calendar" : "Arată sarcinile în calendar",
-    "Enable simplified editor" : "Activează editorul simplificat",
-    "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
-    "Show weekends" : "Arată weekend-uri",
-    "Show week numbers" : "Afișați numerele săptămânilor",
-    "Time increments" : "Incremente de timp",
-    "Default reminder" : "Memento implicit",
+    "General" : "General",
+    "Personal availability settings" : "Setări de disponibilitate",
     "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
     "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
-    "Personal availability settings" : "Setări de disponibilitate",
-    "Show keyboard shortcuts" : "Arată scurtături",
+    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
+    "Show tasks in calendar" : "Arată sarcinile în calendar",
+    "Show weekends" : "Arată weekend-uri",
+    "Show week numbers" : "Afișați numerele săptămânilor",
+    "Editing" : "Se modifică",
+    "Default reminder" : "Memento implicit",
+    "Keyboard shortcuts" : "Scurtături din tastatură",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minute","{duration} de minute"],
     "0 minutes" : "0 minute",
     "_{duration} hour_::_{duration} hours_" : ["{duration} oră","{duration} ore","{duration} de ore"],
@@ -355,6 +353,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Poate că partajarea a fost ștearsă sau a expirat?",
     "Remove participant" : "Elimină participant",
     "Yes" : "Da",
+    "No" : "Nu",
     "Create" : "Crează",
     "from {formattedDate}" : "începând cu {formattedDate}",
     "to {formattedDate}" : "până la {formattedDate}",
@@ -408,6 +407,7 @@ OC.L10N.register(
     "Close" : "Închide",
     "Title" : "Titlu",
     "Participants" : "Participanți",
+    "Submit" : "Trimite",
     "Subscribe to {name}" : "Abonare la {name}",
     "Export {name}" : "Exportă {name}",
     "Anniversary" : "Aniversare",
@@ -497,6 +497,12 @@ OC.L10N.register(
     "Imported {filename}" : "S-a importat {filename}",
     "This is an event reminder." : "Acesta este un memento pentru eveniment.",
     "Appointment not found" : "Programarea nu a fost găsită",
-    "User not found" : "Utilizatorul nu a fost găsit"
+    "User not found" : "Utilizatorul nu a fost găsit",
+    "Automatic ({detected})" : "Automat ({detectat})",
+    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
+    "Enable simplified editor" : "Activează editorul simplificat",
+    "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
+    "Time increments" : "Incremente de timp",
+    "Show keyboard shortcuts" : "Arată scurtături"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
