@@ -111,7 +111,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "Perunu archìviu vàlidu agatadu, annullende s'importatzione",
     "Import partially failed. Imported {accepted} out of {total}." : "Parte de s'importatzione est andada male. Importados {accepted} de {total}.",
     "Automatic" : "Automàticu",
-    "Automatic ({detected})" : "Automàticu ({detected})",
+    "Automatic ({timezone})" : "Automàticu ({timezone})",
     "New setting was not saved successfully." : "Sa cunfiguratzione noa no est istada sarvada in manera curreta.",
     "Navigation" : "Navigatzione",
     "Previous period" : "Tempus in antis",
@@ -124,21 +124,18 @@ OC.L10N.register(
     "Actions" : "Atziones",
     "Create event" : "Crea eventu",
     "Show shortcuts" : "Mustra curtziadòrgios",
-    "Shortcut overview" : "Bista generale de is curtziadòrgiu",
     "or" : "o",
     "No reminder" : "Perunu promemòria",
     "CalDAV link copied to clipboard." : "Ligòngiu CalDAV copiadu in punta de billete.",
     "CalDAV link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu CalDAV in punta de billete.",
-    "Enable birthday calendar" : "Ativa su calendàriu de cumpleannos",
-    "Show tasks in calendar" : "Mustra atividades in su calendàriu",
-    "Enable simplified editor" : "Ativa s'editore semplificadu",
-    "Show weekends" : "Mustra fines de chida",
-    "Show week numbers" : "Mustra nùmeru de chidas",
-    "Time increments" : "Crèschidas de tempus",
-    "Default reminder" : "Promemòria predefinidu",
     "Copy primary CalDAV address" : "Còpia s'indiritzu CalDAV printzipale",
     "Copy iOS/macOS CalDAV address" : "Còpia s'indiritzu CalDAV iOS/macOS",
-    "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu",
+    "Enable birthday calendar" : "Ativa su calendàriu de cumpleannos",
+    "Show tasks in calendar" : "Mustra atividades in su calendàriu",
+    "Show weekends" : "Mustra fines de chida",
+    "Show week numbers" : "Mustra nùmeru de chidas",
+    "Default reminder" : "Promemòria predefinidu",
+    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Update" : "Agiorna",
     "Location" : "Positzione",
     "Description" : "Descritzione",
@@ -241,6 +238,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Mancai sa cumpartzidura est istada cantzellada o est iscadida?",
     "Remove participant" : " Boga·nche partetzipante",
     "Yes" : "Si",
+    "No" : "No",
     "Create" : "Crea",
     "from {formattedDate}" : "dae {formattedDate}",
     "to {formattedDate}" : "a {formattedDate}",
@@ -272,6 +270,7 @@ OC.L10N.register(
     "Selected" : "Seletzionadu",
     "Title" : "Tìtulu",
     "Participants" : "Partetzipantes",
+    "Submit" : "Imbia",
     "Subscribe to {name}" : "Sutaiscrie a {name}",
     "Anniversary" : "Anniversàriu",
     "Appointment" : "Apuntamentu",
@@ -352,6 +351,11 @@ OC.L10N.register(
     "Error while sharing file" : "Errore in sa cumpartzidura de s'archìviu",
     "An error occurred, unable to delete the calendar." : "B'at àpidu un'errore, no at fatu a cantzellare su calendàriu.",
     "Imported {filename}" : "Importadu {filename}",
-    "User not found" : "Utèntzia no agatada"
+    "User not found" : "Utèntzia no agatada",
+    "Automatic ({detected})" : "Automàticu ({detected})",
+    "Shortcut overview" : "Bista generale de is curtziadòrgiu",
+    "Enable simplified editor" : "Ativa s'editore semplificadu",
+    "Time increments" : "Crèschidas de tempus",
+    "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu"
 },
 "nplurals=2; plural=(n != 1);");
